@@ -92,6 +92,18 @@ class XYChart(AbstractChart):
                 self.add(elem)
         return self
 
+    def setYBound(self, lower, upper):
+        self.y_lower_bound = lower
+        self.y_upper_bound = upper
+        self.rangeAxes[0].setBound(lower, upper)
+        return self
+
+    def setXBound(self, lower, upper):
+        self.x_auto_range = False
+        self.x_lower_bound = lower
+        self.x_upper_bound = upper
+        return self
+
 
 class HistogramChart(XYChart):
     def __init__(self, **kwargs):
@@ -193,13 +205,15 @@ class CombinedChart(BaseObject):
 class Plot(BeakerxDOMWidget):
     _view_name = Unicode('PlotView').tag(sync=True)
     _model_name = Unicode('PlotModel').tag(sync=True)
+    _view_module = Unicode('beakerx').tag(sync=True)
+    _model_module = Unicode('beakerx').tag(sync=True)
     model = Dict().tag(sync=True)
     
     def __init__(self, **kwargs):
         super(Plot, self).__init__(**kwargs)
         self.chart = XYChart(**kwargs)
         self.model = self.chart.transform()
-    
+
     def add(self, item):
         self.chart.add(item)
         self.model = self.chart.transform()
@@ -213,6 +227,35 @@ class Plot(BeakerxDOMWidget):
         self.model = self.chart.transform()
         return self
 
+    def setXBound(self, *args):
+        if len(args) == 1 and isinstance(args[0], list):
+            arg_list = args[0]
+            if len(arg_list) == 2:
+                self.chart.setXBound(arg_list[0], arg_list[1])
+            else:
+                raise ValueError('to set the x bound, the list needs to be of size=2.')
+        else:
+            self.chart.setXBound(args[0], args[1])
+        self.model = self.chart.transform()
+        return self
+
+    def setYBound(self, *args):
+        if len(args) == 1 and isinstance(args[0], list):
+            arg_list = args[0]
+            if len(arg_list) == 2:
+                self.chart.setYBound(arg_list[0], arg_list[1])
+            else:
+                raise ValueError('to set the y bound, the list needs to be of size=2.')
+        else:
+            self.chart.setYBound(args[0], args[1])
+        self.model = self.chart.transform()
+        return self
+
+    def _ipython_display_(self, **kwargs):
+        self.model = self.chart.transform()
+        super(Plot, self)._ipython_display_(**kwargs)
+
+
 class CategoryPlot(BeakerxDOMWidget):
     _view_name = Unicode('PlotView').tag(sync=True)
     _model_name = Unicode('PlotModel').tag(sync=True)
@@ -224,12 +267,15 @@ class CategoryPlot(BeakerxDOMWidget):
         super(CategoryPlot, self).__init__(**kwargs)
         self.chart = CategoryChart(**kwargs)
         self.model = self.chart.transform()
-    
+
     def add(self, item):
         self.chart.add(item)
         self.model = self.chart.transform()
         return self
 
+    def _ipython_display_(self, **kwargs):
+        self.model = self.chart.transform()
+        super(CategoryPlot, self)._ipython_display_(**kwargs)
 
 class HeatMap(BeakerxDOMWidget):
     _view_name = Unicode('PlotView').tag(sync=True)
@@ -265,7 +311,7 @@ class HeatMap(BeakerxDOMWidget):
             self.chart.color = color
         
         self.chart.type = 'HeatMap'
-        
+
         self.model = self.chart.transform()
 
 
@@ -304,7 +350,7 @@ class TreeMap(BeakerxDOMWidget):
         super(TreeMap, self).__init__()
         self.chart = TreeMapChart(**kwargs)
         self.model = self.chart.transform()
-    
+
     def setColorProvider(self, provider):
         self.chart.colorProvider = provider
         self.model = self.chart.transform()
@@ -444,7 +490,7 @@ class CombinedPlot(BeakerxDOMWidget):
         super(CombinedPlot, self).__init__(**kwargs)
         self.chart = CombinedChart(**kwargs)
         self.model = self.chart.transform()
-    
+
     def add(self, item, weight):
         if isinstance(item.chart, XYChart):
             self.chart.plots.append(item.chart)
